@@ -6,6 +6,7 @@ TABLES = {
     'pluto_18v2': {'pluto_18v2': 800_000},
     'pluto_19v1': {'pluto_19v1': 800_000},
     'pluto_19v2': {'pluto_19v2': 800_000},
+    'pluto_20v8': {'pluto_20v8': 800_000},
     'dobjobs': {'dobjobs': 1_000_000},
     'dob_violations': {'dob_violations': 2_000_000},
     'ecb_violations': {'ecb_violations': 1_300_000},
@@ -51,7 +52,20 @@ TABLES = {
     },
     'oath_hearings': {'oath_hearings': 10_000_000},
     'hpd_vacateorders': {'hpd_vacateorders': 4_000},
-    'j51_exemptions': {'j51_exemptions': 4_000_000}
+    'j51_exemptions': {'j51_exemptions': 4_000_000},
+    'oca': {
+        'oca_index': 1_300_000,
+        'oca_causes': 1_300_000,
+        'oca_addresses': 1_300_000,
+        'oca_parties': 3_400_000,
+        'oca_events': 2_500_000,
+        'oca_appearances': 2_500_000,
+        'oca_appearance_outcomes': 2_500_000,
+        'oca_motions': 700_000,
+        'oca_decisions': 650_000,
+        'oca_judgments': 600_000,
+        'oca_warrants': 600_000
+    }
 }
 
 
